print("import: u'socketio'")
import socketio

print("import: u'socketio.base_manager'")
import socketio.base_manager

print("import: u'socketio.kombu_manager'")
import socketio.kombu_manager

print("import: u'socketio.middleware'")
import socketio.middleware

print("import: u'socketio.namespace'")
import socketio.namespace

print("import: u'socketio.packet'")
import socketio.packet

print("import: u'socketio.pubsub_manager'")
import socketio.pubsub_manager

print("import: u'socketio.redis_manager'")
import socketio.redis_manager

print("import: u'socketio.server'")
import socketio.server

